# Auto Symbol Description [![Build Status](https://travis-ci.org/kentor/babel-plugin-auto-symbol-description.svg)](https://travis-ci.org/kentor/babel-plugin-auto-symbol-description)

A [Babel][b] plugin to automatically set [Symbol][s] descriptions.

## Use Cases

### Redux
Very useful with Redux if you use Symbols for action types:

In:

```js
// TodoActions.js
export const CREATE = Symbol();
export const CREATE_SUCCESS = Symbol();
export const CREATE_FAILURE = Symbol();
```

Out (something like this):

```js
// TodoActions.js
export const CREATE = Symbol('TodoActions.CREATE');
export const CREATE_SUCCESS = Symbol('TodoActions.CREATE_SUCCESS');
export const CREATE_FAILURE = Symbol('TodoActions.CREATE_FAILURE');
```

Then use these constants in a reducer:

```
// TodoReducer.js
import * as TodoActions from '../actions/TodoActions';

export function TodoReducer(state, action) {
  switch (action) {
  case TodoActions.CREATE:
    // Handle create
    break;
  case TodoActions.CREATE_SUCCESS:
    // Handle create success
    break;
  case TodoActions.CREATE_FAILURE:
    // Handle create failure
    break;
  default:
    return state;
  }
}
```

Symbol descriptions are only useful for debugging, so idealy you would only
include this transformation in development.

## Installation

```
npm install -D babel-plugin-auto-symbol-description
```

## Notes

This plugin won't transform any `Symbol` calls with an argument, and it only
works for assignments and variable declarations for now. Let me know if there is
demand for the transformation when setting an object property or any other use
cases.

[b]: http://babeljs.io/
[s]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol


[b]: http://babeljs.io/
[s]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Symbol
